==> media_service-tomato-20201229.053228-249-sources.jar: com/jz/jar/media/service/UserAiService.java <==
package com.jz.jar.media.service;

import java.util.Collection;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;

import com.jz.jar.media.repository.UserAiRepository;
import com.jz.jooq.media.tables.pojos.UserAiHomework;
import com.jz.jooq.media.tables.pojos.UserAiLesson;
import com.jz.jooq.media.tables.pojos.UserAiLessonSection;
import com.jz.jooq.media.tables.pojos.UserAiPack;

@Lazy
@Service
public class UserAiService {

	@Autowired
	private UserAiRepository userAiRepository;

	public void saveHomework(String suid, String pid, String aid, String materialId, String pic) {
		userAiRepository.saveHomework(suid, pid, aid, materialId, pic);
	}

	public List<UserAiHomework> getHomeworks(String suid, String pid, String aid) {
		return userAiRepository.getHomeworks(suid, pid, aid);
	}

	public List<UserAiHomework> mutiGetHomework(String suid, String pid, String aid, Collection<String> materialIds) {
		return userAiRepository.mutiGetHomework(suid, pid, aid, materialIds);
	}

	public void savePack(String uid, String suid, String pid, long openTime, String cid) {
		userAiRepository.savePack(uid, suid, pid, openTime, cid);
	}

	public UserAiPack getPack(String uid, String pid) {
		return userAiRepository.getPack(uid, pid);
	}

	public int cntPackByCid(String cid) {
		return userAiRepository.cntPackByCid(cid);
	}

	public void saveLesson(String suid, String pid, String aid, int status, String currentSectionId,
			String currentMaterialId) {
		userAiRepository.saveLesson(suid, pid, aid, status, currentSectionId, currentMaterialId);
	}

	public List<UserAiLesson> getLessons(String suid, String pid) {
		return userAiRepository.getLessons(suid, pid);
	}

	public UserAiLesson getLesson(String suid, String pid, String aid) {
		return userAiRepository.getLesson(suid, pid, aid);
	}

	public void saveSection(String suid, String pid, String aid, String sectionId, int status, String currentMaterialId) {
		userAiRepository.saveSection(suid, pid, aid, sectionId, status, currentMaterialId);
	}

	public List<UserAiLessonSection> getSections(String suid, String pid, String aid) {
		return userAiRepository.getSections(suid, pid, aid);
	}

	public UserAiLessonSection getSection(String suid, String pid, String aid, String sectionId) {
		return userAiRepository.getSection(suid, pid, aid, sectionId);
	}

}

==> media_service-tomato-20210119.110011-256-sources.jar: com/jz/jar/media/service/UserAiService.java <==
package com.jz.jar.media.service;

import java.util.Collection;
import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Lazy;
import org.springframework.stereotype.Service;

import com.jz.jar.media.repository.UserAiRepository;
import com.jz.jooq.media.tables.pojos.UserAiHomework;
import com.jz.jooq.media.tables.pojos.UserAiLesson;
import com.jz.jooq.media.tables.pojos.UserAiLessonSection;
import com.jz.jooq.media.tables.pojos.UserAiPack;

@Lazy
@Service
public class UserAiService {

	@Autowired
	private UserAiRepository userAiRepository;

	public void saveHomeworkPic(String suid, String pid, String aid, String sectionId, String materialId, String pic) {
		userAiRepository.saveHomeworkPic(suid, pid, aid, sectionId, materialId, pic);
	}

	public void saveHomeworkAudio(String suid, String pid, String aid, String sectionId, String materialId, String audio) {
		userAiRepository.saveHomeworkAudio(suid, pid, aid, sectionId, materialId, audio);
	}

	public List<UserAiHomework> getHomeworks(String suid, String pid, String aid) {
		return userAiRepository.getHomeworks(suid, pid, aid);
	}

	public List<UserAiHomework> mutiGetHomework(String suid, String pid, String aid, Collection<String> materialIds) {
		return userAiRepository.mutiGetHomework(suid, pid, aid, materialIds);
	}

	public void savePack(String uid, String suid, String pid, long openTime, String cid) {
		userAiRepository.savePack(uid, suid, pid, openTime, cid);
	}

	public UserAiPack getPack(String uid, String pid) {
		return userAiRepository.getPack(uid, pid);
	}

	public int cntPackByCid(String cid) {
		return userAiRepository.cntPackByCid(cid);
	}

	public void saveLesson(String suid, String pid, String aid, int status, String currentSectionId,
			String currentMaterialId) {
		userAiRepository.saveLesson(suid, pid, aid, status, currentSectionId, currentMaterialId);
	}

	public List<UserAiLesson> getLessons(String suid, String pid) {
		return userAiRepository.getLessons(suid, pid);
	}

	public UserAiLesson getLesson(String suid, String pid, String aid) {
		return userAiRepository.getLesson(suid, pid, aid);
	}

	public void saveSection(String suid, String pid, String aid, String sectionId, int status, String currentMaterialId) {
		userAiRepository.saveSection(suid, pid, aid, sectionId, status, currentMaterialId);
	}

	public List<UserAiLessonSection> getSections(String suid, String pid, String aid) {
		return userAiRepository.getSections(suid, pid, aid);
	}

	public UserAiLessonSection getSection(String suid, String pid, String aid, String sectionId) {
		return userAiRepository.getSection(suid, pid, aid, sectionId);
	}

}
